run

Function run 

pub async fn run(args: Args) -> Result<(), ErdifyError>
Application entry point.

Errors

Returns an ErdifyError if the url is invalid, if the connection or a query fails, if no table matches the filters, or if writing the output file fails.