Module schema

Module schema 

Structs

CheckConstraint
CHECK constraint.
Column
Column of a table.
ForeignKey
Foreign key constraint (potentially multi-column).
IndexInfo
Information about an index.
Table
Represents a table with all its metadata.
UniqueConstraint
UNIQUE constraint.

Enums

TableKind
Kind of catalog relation an entity was extracted from.

Constants

SYSTEM_SCHEMAS
System schemas always excluded from generation.

Functions

filter_tables
Filters tables based on the specified schemas and tables.