Structs
- Check
Constraint - CHECK constraint.
- Column
- Column of a table.
- Foreign
Key - Foreign key constraint (potentially multi-column).
- Index
Info - Information about an index.
- Table
- Represents a table with all its metadata.
- Unique
Constraint - UNIQUE constraint.
Enums
- Table
Kind - Kind of catalog relation an entity was extracted from.
Constants
- SYSTEM_
SCHEMAS - System schemas always excluded from generation.
Functions
- filter_
tables - Filters tables based on the specified schemas and tables.